summaryrefslogtreecommitdiff
path: root/console-client/bdf.h
diff options
context:
space:
mode:
authorJonathan Neuschäfer <j.neuschaefer@gmx.net>2011-08-15 22:10:09 +0200
committerSamuel Thibault <samuel.thibault@ens-lyon.org>2011-08-20 18:36:33 +0200
commitc0eaf0fad88f15c843098a43ca2cadbf009ce094 (patch)
tree7b129c5055ded1aa400d34409d64bbab363b3e9e /console-client/bdf.h
parent5a3976828225947d333ff2326d04f8b20e48e072 (diff)
fix common misspellings
* Fix spelling with codespell[1] and manually review it. [1] http://git.profusion.mobi/cgit.cgi/lucas/codespell/
Diffstat (limited to 'console-client/bdf.h')
-rw-r--r--console-client/bdf.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/console-client/bdf.h b/console-client/bdf.h
index 1f0bce41..17cd0235 100644
--- a/console-client/bdf.h
+++ b/console-client/bdf.h
@@ -32,17 +32,17 @@
types of the arguments, so we treat a string as an 8-bit string
which must not contain a binary null, and a number like an integer
as an int. Leading and trailing white space are removed, multiple
- spaces that seperate arguments are replaced by a single white
+ spaces that separate arguments are replaced by a single white
space, and empty lines are ignored. */
/* Possible error values returned by the BDF functions. */
typedef enum
{
/* No error occured. This is guaranteed to be zero. */
BDF_NO_ERROR = 0,
/* A system error occured. The caller should consult errno. */
BDF_SYSTEM_ERROR,
/* All following errors indicate that the file is not a valid BDF
@@ -200,7 +200,7 @@ typedef struct bdf_font *bdf_font_t;
/* Read the font from stream FILE, and return it in FONT. If
LINECOUNT is not zero, it will contain the number of lines in the
- file at success, and the current line an error occured at
+ file at success, and the current line an error occurred at
failure. */
bdf_error_t bdf_read (FILE *file, bdf_font_t *font, int *linecount);
@@ -32,17 +32,17 @@
typedef enum
{
- /* No error occured. This is guaranteed to be zero. */
+ /* No error occurred. This is guaranteed to be zero. */
BDF_NO_ERROR = 0,
@@ -32,17 +32,17 @@
BDF_NO_ERROR = 0,
- /* A system error occured. The caller should consult errno. */
+ /* A system error occurred. The caller should consult errno. */
BDF_SYSTEM_ERROR,
/* All following errors indicate that the file is not a valid BDF